@@ -14,7 +14,7 @@
 ** This file contains functions for allocating memory, comparing
 ** strings, and stuff like that.
 **
-** $Id: util.c,v 1.25 2004/09/10 15:33:02 matt Exp $
+** $Id: util.c,v 1.26 2004/09/21 14:34:46 matt Exp $
 */
 #include "sqliteInt.h"
 #include <stdarg.h>
@@ -27,11 +27,11 @@ void print_stack_trace(){
   int i;
   int n = backtrace(bt, 30);
 
-  fprintf(stderr, "STACK: ");
+  sqlite3DebugPrintf("STACK: ");
   for(i=0; i<n;i++){
-    fprintf(stderr, "%p ", bt[i]);
+    sqlite3DebugPrintf("%p ", bt[i]);
   }
-  fprintf(stderr, "\n");
+  sqlite3DebugPrintf("\n");
 }
 #else
 #define print_stack_trace()
@@ -452,7 +452,7 @@ void sqlite3SetNString(char **pz, ...){
 ** should be called with err_code set to SQLITE_OK and zFormat set
 ** to NULL.
 */
-void sqlite3Error(sqlite *db, int err_code, const char *zFormat, ...){
+void sqlite3Error(sqlite3 *db, int err_code, const char *zFormat, ...){
   if( db && (db->pErr || (db->pErr = sqlite3ValueNew())) ){
     db->errCode = err_code;
     if( zFormat ){
@@ -591,7 +591,7 @@ int sqlite3StrNICmp(const char *zLeft, const char *zRight, int N){
 ** the string is numeric and contains the '.' character, set *realnum
 ** to TRUE (otherwise FALSE).
 **
-** Am empty string is considered non-numeric.
+** An empty string is considered non-numeric.
 */
 int sqlite3IsNumber(const char *z, int *realnum, u8 enc){
   int incr = (enc==SQLITE_UTF8?1:2);
@@ -722,7 +722,7 @@ int sqlite3atoi64(const char *zNum, i64 *pNum){
 ** 32-bit signed integer, return TRUE.  Otherwise return FALSE.
 **
 ** This routine returns FALSE for the string -2147483648 even that
-** that number will, in theory fit in a 32-bit integer.  But positive
+** that number will in fact fit in a 32-bit integer.  But positive
 ** 2147483648 will not fit in 32 bits.  So it seems safer to return
 ** false.
 */
@@ -782,7 +782,7 @@ int sqlite3FitsIn64Bits(const char *zNum){
 ** call to sqlite3_close(db) and db has been deallocated.  And we do
 ** not want to write into deallocated memory.
 */
-int sqlite3SafetyOn(sqlite *db){
+int sqlite3SafetyOn(sqlite3 *db){
   if( db->magic==SQLITE_MAGIC_OPEN ){
     db->magic = SQLITE_MAGIC_BUSY;
     return 0;
@@ -798,7 +798,7 @@ int sqlite3SafetyOn(sqlite *db){
 ** Return an error (non-zero) if the magic was not SQLITE_MAGIC_BUSY
 ** when this routine is called.
 */
-int sqlite3SafetyOff(sqlite *db){
+int sqlite3SafetyOff(sqlite3 *db){
   if( db->magic==SQLITE_MAGIC_BUSY ){
     db->magic = SQLITE_MAGIC_OPEN;
     return 0;
@@ -818,7 +818,7 @@ int sqlite3SafetyOff(sqlite *db){
 ** This routine is used to try to detect when API routines are called
 ** at the wrong time or in the wrong sequence.
 */
-int sqlite3SafetyCheck(sqlite *db){
+int sqlite3SafetyCheck(sqlite3 *db){
   if( db->pVdbe!=0 ){
     db->magic = SQLITE_MAGIC_ERROR;
     return 1;
@@ -994,3 +994,31 @@ void *sqlite3HexToBlob(const char *z){
   }
   return zBlob;
 }
+
+#if defined(SQLITE_TEST)
+/*
+** Convert text generated by the "%p" conversion format back into
+** a pointer.
+*/
+void *sqlite3TextToPtr(const char *z){
+  void *p;
+  u64 v;
+  u32 v2;
+  if( z[0]=='0' && z[1]=='x' ){
+    z += 2;
+  }
+  v = 0;
+  while( *z ){
+    v = (v<<4) + hexToInt(*z);
+    z++;
+  }
+  if( sizeof(p)==sizeof(v) ){
+    p = *(void**)&v;
+  }else{
+    assert( sizeof(p)==sizeof(v2) );
+    v2 = (u32)v;
+    p = *(void**)&v2;
+  }
+  return p;
+}
+#endif
